clp\_ffi\_py.ir package
=======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   clp_ffi_py.ir.native
   clp_ffi_py.ir.query_builder
   clp_ffi_py.ir.readers

Module contents
---------------

.. automodule:: clp_ffi_py.ir
   :members:
   :undoc-members:
   :show-inheritance:
